<?php 
class AdminModel extends CI_Model
{
	function __construct()
	{
		$this->load->database();
	}

	public function publish($table, $field, $value, $id)
	{
		$this->db->set($field, $value);
		$this->db->where($table.'_id', $id);
		$this->db->update($table);
	}

	public function unpublish($table, $field, $value, $id)
	{
		$this->db->set($field, $value);
		$this->db->where($table.'_id', $id);
		$this->db->update($table);
	}

	public function delete($table, $id, $image_column, $image_path)
	{
		/* remove old upload images from directory */
		$this->delete_previous_images($table, $id, $image_column, str_replace('+', '/', $image_path));

		$this->db->where($table.'_id', $id);
		$this->db->delete($table);
	}

	public function multi_publish($table, $field, $value, $ids)
	{
		$this->db->set($field, $value);
		$this->db->where_in($table.'_id', explode(',',$ids));
		$this->db->update($table);
	}

	public function multi_unpublish($table, $field, $value, $ids)
	{
		$this->db->set($field, $value);
		$this->db->where_in($table.'_id', explode(',',$ids));
		$this->db->update($table);
	}

	public function multi_delete($table, $ids, $image_column, $image_path)
	{
		/* remove old upload images from directory */
		$this->delete_previous_images($table, $ids, $image_column, str_replace('+', '/', $image_path));

		$this->db->where_in($table.'_id', explode(',',$ids));
		$this->db->delete($table);
	}

    public function json_priority($table, $field, $value, $id)
    {   
      $this->db->set($field, $value);
      $this->db->where($table.'_id', $id);
      $this->db->update($table);
    } 

    public function delete_previous_images($table, $ids, $image_column, $image_path)
    {
    	/* validation for multiple images */
    	$image_column = explode(',', $image_column);
    	$image_path = explode(',', $image_path);
    	
    	/* mysql - get all image names form database */
    	$this->db->select($image_column);
    	$this->db->from(
    	$table);
    	$this->db->where_in($table.'_id', explode(',', $ids));
    	$query = $this->db->get();

    	/* remove old upload images from directory */
    	foreach($query->result_array() as $result)
    	{
    		foreach($image_column as $index => $value)
    		if(isset($result[$image_column[$index]]) && !empty($result[$image_column[$index]]) && file_exists($image_path[$index].'/'.$result[$image_column[$index]]))
    			unlink($image_path[$index].'/'.$result[$image_column[$index]]);
    	}		
    }

    /* set teme color */
    public function theme_color($admin_theme_color, $tbl_admin_id)
    {   
    	$this->db->set('tbl_admin.admin_theme_color', $admin_theme_color);
		$this->db->where('tbl_admin.tbl_admin_id', $tbl_admin_id);
		$this->db->update('tbl_admin');
		
       	$this->session->set_userdata('admin_theme_color', $admin_theme_color);
        return true;
    }

    /* import post - common */
    public function import_post($data, $table_name, $column_array, $column_frk_array)
    {
      $insert_count = 0;

      if(!empty($data) &&  !empty($table_name) && !empty($column_array))
      {
        $column_key_array = array(); 
        $column_frk_key_array = array(); 

        $insert_frk_flag = false;
        $insert_flag = false;

        if(isset($data->sheets[0]['cells'][2]) && isset($column_key_array))
        {
          foreach ($data->sheets[0]['cells'][2] as $key => $value)
          { 
            if(array_search(str_replace(' ', '_', strtolower($value)), $column_array) !== FALSE)
            {
              $column_key_array[str_replace(' ', '_', strtolower($value))]  = $key;
              $insert_flag = true;
              
              if(isset($column_frk_array) && !empty($column_frk_array))
              {
                if(array_search(str_replace(' ','_', strtolower($value)), $column_frk_array) !== FALSE)
                { 
                  $index = array_search(str_replace(' ','_', strtolower($value)), $column_frk_array);
                  $column_frk_key_array[str_replace(' ', '_', strtolower($value))]  = $key.','.$index;
                  $insert_frk_flag = true;
                }
              }
            }
            else
            {
              $insert_flag = false; break;
            }
          }
        }
        
        if($insert_flag)
        {
          if(isset($data->sheets[0]) && isset($column_key_array))
          {
            for($i = 4; $i < $data->sheets[0]['numRows'] + 1; $i++)
            {
              	if(isset($data->sheets[0]['cells'][$i]) && !empty($data->sheets[0]['cells'][$i]))
              	{
	              foreach($data->sheets[0]['cells'][$i] as $excel_key => $excel_value)
	              {
	                foreach($column_key_array as $column_key => $column_value)
	                { 
	                  $temp_flag = true;
	                  if($excel_key == $column_value && $insert_frk_flag)
	                  { 
	                    if(isset($column_frk_key_array))
	                    {
	                      foreach($column_frk_key_array as $frk_key => $frk_value)
	                      {
	                        if($excel_key == explode(',', $frk_value)[0])
	                        {
	                          $temp_flag = false;
	                          $this->db->select(explode(',', $frk_value)[2].', '.$frk_key);
	                          $this->db->from(explode(',', $frk_value)[1]);
	                          $this->db->where($frk_key, $excel_value);

	                          $result = $this->db->get()->result_array();
	                          if(!empty($result))
	                          {
	                            $tbl_frk_id = $result[0][explode(',', $frk_value)[2]]; 
	                            $this->db->set(explode(',', $frk_value)[2], $tbl_frk_id); 
	                          }
	                          else
	                          {
	                            $this->db->set($frk_key, $excel_value);
	                            $this->db->insert(explode(',', $frk_value)[1]);
	                            $tbl_frk_id = $this->db->insert_id(); 
	                            $this->db->set(explode(',', $frk_value)[2], $tbl_frk_id); break;
	                          }
	                        }   
	                      }
	                    }
	                  }
	                  if($temp_flag && $excel_key == $column_value)
	                  {
	                    $this->db->set($column_key, $data->sheets[0]['cells'][$i][$excel_key]); 
	                  }
	                } 
	              }
	              $this->db->insert($table_name);
	              $insert_count ++;
          	  	}
            }
          }
          return $insert_count;
        }
      }
      return $insert_count;
    }

    /* mail post - common */
    public function create_view_mail($mail_post_content)
	{
		extract($mail_post_content);
		
		$message='<div style="border:1px solid #000;">
		<header class="header" style="background:darkorange;height:70px;">
			<div class="main-heading">		
			<h3 style="margin-top: 0px;padding-left:10px;padding-top:25px;">'.((isset($mail_post_content['detail_mail_title'])) ? $mail_post_content['detail_mail_title'] : 'Dummy Title').'</h3>
			</div>
		</header>';
		
		if(isset($mail_post_content) && !empty($mail_post_content))
		{
			foreach($mail_post_content as $post_content)
			{
				$message.='
				<div style="margin-left:20px;margin-right:20px;margin-bottom:20px;">';
				
				foreach($post_content as $key => $value)
				{
					if (preg_match('/(\.jpg|\.png|\.bmp)$/i', $value))
					{
						$message.='
						<p><b>'.ucwords(str_replace('_',' ',$key)).'</b> -</p>
						<div style="width:auto; height:auto;text-align:center;">
						<img src=""'.base_url().'../upload/'.((isset($mail_post_content['detail_mail_title'])) ? $mail_post_content['detail_mail_title'] : '.').'/'.$value.'"" style="width:500px; height:100%;">
						</div>
						';
					}
					else
					{
						$message.='
						<p><b>'.ucwords(str_replace('_',' ',$key)).'</b> - <span>'.$value.'</span></p>
						';
					}
				}
				
				$message.='
				</div><hr>';
			}
		}
		
		$message.='
		<footer style="height:50px;background:darkorange"></footer>
		</div>';
		
		return $message;
	}

	/* SQL query user defined functions*/

	/*
	select - array / string
	table - string
	where - array / string
	orwhere - array / string
	where_in = 'tbl_product.tbl_product_id | '.$ids; //string ids = 150,250,411
	order_by - string
	group_by - string
	joins - array / string
	= array('tbl_pages | tbl_columns.tbl_pages_id = tbl_pages.tbl_pages_id | inner', 'tbl_projects | tbl_pages.tbl_projects_id = tbl_projects.tbl_projects_id | inner');
	= 'tbl_pages | tbl_columns.tbl_pages_id = tbl_pages.tbl_pages_id | inner';
	like - array / string - array('col' => 'val') or array('col' => array('val','after/before'))
	orlike - array / string - array('col' => 'val') or array('col' => array('val','after/before'))
	limit - string / int
	offset - int / string
	having - array / string
	*/
	public function op_mysql_select($select, $table, $where = null, $orwhere = null, $where_in = null, $joins = null, $order_by = null, $group_by = null, $like = null, $orlike = null, $limit = null, $offset = null, $having = null)
	{   
	    $this->db->select($select);
	    if(isset($joins) && !empty($joins))
	    {
	        if(is_array($joins))
	        {  
	            foreach($joins as $join)
	            {
	                $join = explode('|', $join);
	                if(count($join) == 3)
	                    $this->db->join($join[0], $join[1], $join[2]);
	                if(count($join) == 2)
	                    $this->db->join($join[0], $join[1]);
	            }
	        }
	        else 
	        {
	            $join = explode('|', $joins);
	            if(count($join) == 3)
	                $this->db->join($join[0], $join[1], $join[2]);
	            if(count($join) == 2)
	                $this->db->join($join[0], $join[1]);
	        }
	    }
	    if(isset($where) && !empty($where))
	        $this->db->where($where);
	    if(isset($orwhere) && !empty($orwhere))
	        $this->db->or_where($orwhere);
     	if(isset($where_in) && !empty($where_in))
          	$this->db->where_in(explode('|', $where_in)[0], array_map('intval', explode(',', explode('|', $where_in)[1])));
	    
		$like_flag = true;
      if(isset($like) && !empty($like))
      {
        foreach($like as $like_key => $like_value)
        {
          if(is_array($like_value))
          {
            $like_flag = false;
            $this->db->like($like_key, $like_value[0], $like_value[1]);
          }
        }
      }
      if($like_flag && isset($like) && !empty($like))
          $this->db->like($like);

      $or_like_flag = true;
      if(isset($orlike) && !empty($orlike))
      {
        foreach($orlike as $orlike_key => $orlike_value)
        {
          if(is_array($orlike_value))
          {
            $or_like_flag = false;
            $this->db->or_like($orlike_key, $orlike_value[0], $orlike_value[1]);
          }
        }
      }  
      if($or_like_flag && isset($orlike) && !empty($orlike))
          $this->db->or_like($orlike);
      
      if(isset($group_by) && !empty($group_by))
	        $this->db->group_by($group_by);
	    if(isset($order_by) && !empty($order_by))
	        $this->db->order_by($order_by);
	    if(isset($having) && !empty($having))
	        $this->db->having($having);
	    
	    $query = $this->db->get($table, $limit, $offset);
	    return $query->result_array();
	}

	/*
	table - string
	data - array / string
	*/
	public function op_mysql_insert($table, $data)
	{   
		if(isset($data) && !empty($data))
			$this->db->insert($table, $data);
		return $this->db->insert_id();
	}

	/*
	table - string
	set - array / string
	where - array / string
	*/
	public function op_mysql_update($table, $set, $where = null)
	{
		if(isset($where) && !empty($where))
			$this->db->where($where);
	    if(isset($set) && !empty($set))
			$this->db->update($table, $set);

		return $this->db->affected_rows();
	}

	/*
	table - string
	where - array / string
	*/
	public function op_mysql_delete($table, $where = null)
	{   
		if(isset($where) && !empty($where))
			$this->db->where($where);
	    $this->db->delete($table);
	    
	    return $this->db->affected_rows();
	}

	/*
	smtp - send mail
	*/
	public function send_mail($from, $to, $cc='', $bcc='', $name, $subject, $message, $attachment = null)
	{
		//echo $from.', '.$to.', '.$name.', '.$subject.', '.$message; //die;
		
		$contact_logo = base_url().'../assets/images/logo.png';
		$contact_logo_alternate = 'ingenious-logo';
		$contact_office = 'ingenious';
		$contact_email = 'info-ingenious@gmail.com';
		$contact_telephone = '1-844-358-1023';
		$contact_website = 'http://www.ingenious.com';
		
		$this->load->model('ContactModel');
		$contact_content = $this->ContactModel->content();
		if(!empty($contact_content))
		{
			if(isset($contact_content['contact_logo']) && !empty($contact_content['contact_logo']))
				$contact_logo = base_url().'../upload/contact/'.$contact_content['contact_logo'];

			if(isset($contact_content['contact_logo_alternate']) && !empty($contact_content['contact_logo_alternate']))
				$contact_logo_alternate = $contact_content['contact_logo_alternate'];

			if(isset($contact_content['contact_office']) && !empty($contact_content['contact_office']))
				$contact_office = $contact_content['contact_office'];

			/*if(isset($contact_content['contact_email']) && !empty($contact_content['contact_email']))
				$contact_email = $contact_content['contact_email'];

			if(isset($contact_content['contact_telephone']) && !empty($contact_content['contact_telephone']))
				$contact_telephone = $contact_content['contact_telephone'];*/

			if(isset($contact_content['contact_website']) && !empty($contact_content['contact_website']))
				$contact_website = $contact_content['contact_website'];
		}
			
		$profile_message ='<br><br>-----'."\r\n";
		$profile_message.='<p>If you have any questions or trouble on please contact us at <a href="'.base_url().'../">ingenious</a><br/>'."\r\n";
		$profile_message.='Website : <a href="'.$contact_website.'">'.$contact_website.'</a> <br/> Contact : '.$this->session->userdata('admin_contact').' <br/> Email : '.$this->session->userdata('admin_email').' <br/><br/> Thank You <br/><b>'.$this->session->userdata('admin_name').'</b><br/><b> Admin | '.$contact_office.' | Support Services</b> <br/>';
		$profile_message.= '<a href="'.base_url().'../"><img style="width:30%" src="'.$contact_logo.'" alt="'.$contact_logo_alternate.'"></a>';
		$profile_message.='<hr/><i>* The location is approximate and determined by the IP address it was coming from.</i>'."\r\nThis email can't receive replies.";
		$profile_message.=''."\r\n"; 

		$config = Array(
                    'protocol' => 'smtp',
                    'smtp_host' => 'ssl://smtp.googlemail.com',
                    'smtp_port' => 465,
                    'smtp_user' => 'email@gmail.com',
                    'smtp_pass' => 'pass',
                );
		$this->load->library('email', $config);
		//$this->load->library('email');
		$this->email->set_mailtype('html');
		$this->email->from('no-reply@oysterwebtesting.in', $name);
		$this->email->to($to);
		$this->email->reply_to($from);
		if(!empty($cc))
			$this->email->cc($cc);
		if(!empty($bcc))
			$this->email->bcc($bcc);

		$this->email->subject($subject);
		$this->email->message($message . $profile_message);

		if(!empty($attachment))
      		$this->email->attach($attachment,'image/jpeg/pdf');

		return $this->email->send();
	}
}
	?>